@@ -31,37 +31,41 @@ public class vtkCommand extends vtkObjectBase
   public int GetEventIdFromString(String id0)
     { return GetEventIdFromString_5(id0); }
 
-  private native void SetAbortFlag_6(int id0);
+  private native boolean EventHasData_6(int id0);
+  public boolean EventHasData(int id0)
+    { return EventHasData_6(id0); }
+
+  private native void SetAbortFlag_7(int id0);
   public void SetAbortFlag(int id0)
-    { SetAbortFlag_6(id0); }
+    { SetAbortFlag_7(id0); }
 
-  private native int GetAbortFlag_7();
+  private native int GetAbortFlag_8();
   public int GetAbortFlag()
-    { return GetAbortFlag_7(); }
+    { return GetAbortFlag_8(); }
 
-  private native void AbortFlagOn_8();
+  private native void AbortFlagOn_9();
   public void AbortFlagOn()
-    { AbortFlagOn_8(); }
+    { AbortFlagOn_9(); }
 
-  private native void AbortFlagOff_9();
+  private native void AbortFlagOff_10();
   public void AbortFlagOff()
-    { AbortFlagOff_9(); }
+    { AbortFlagOff_10(); }
 
-  private native void SetPassiveObserver_10(int id0);
+  private native void SetPassiveObserver_11(int id0);
   public void SetPassiveObserver(int id0)
-    { SetPassiveObserver_10(id0); }
+    { SetPassiveObserver_11(id0); }
 
-  private native int GetPassiveObserver_11();
+  private native int GetPassiveObserver_12();
   public int GetPassiveObserver()
-    { return GetPassiveObserver_11(); }
+    { return GetPassiveObserver_12(); }
 
-  private native void PassiveObserverOn_12();
+  private native void PassiveObserverOn_13();
   public void PassiveObserverOn()
-    { PassiveObserverOn_12(); }
+    { PassiveObserverOn_13(); }
 
-  private native void PassiveObserverOff_13();
+  private native void PassiveObserverOff_14();
   public void PassiveObserverOff()
-    { PassiveObserverOff_13(); }
+    { PassiveObserverOff_14(); }
 
   public vtkCommand() { super(); }
 
